/*
 *   moolua-tests.h
 *
 *   Copyright (C) 2004-2010 by Yevgen Muntyan <emuntyan@users.sourceforge.net>
 *
 *   This file is part of medit.  medit is free software; you can
 *   redistribute it and/or modify it under the terms of the
 *   GNU Lesser General Public License as published by the
 *   Free Software Foundation; either version 2.1 of the License,
 *   or (at your option) any later version.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with medit.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MOO_LUA_TESTS_H
#define MOO_LUA_TESTS_H

#include "mooutils/moo-test-macros.h"

G_BEGIN_DECLS

void    moo_test_lua    (MooTestOptions opts);

G_END_DECLS

#endif /* MOO_LUA_TESTS_H */
